<?php

namespace Teknisa\FIN\Modules\ContaPagar\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Fiscal\Entities\Notafiscal;
use Teknisa\Model\Financeiro\Entities\Ajbolpag;
use Teknisa\Model\Financeiro\Entities\Ajctpagar;
use Teknisa\Model\Financeiro\Entities\Boletpagar;
use Teknisa\Model\Financeiro\Entities\Contapagar;
use Teknisa\Model\Financeiro\Entities\Ratctpagar;
use Teknisa\Model\Financeiro\Entities\Adiantapagar;
use Teknisa\Model\Financeiro\Entities\Devolucaopag;

/**
 * Class ParcelamentoTituloFactory
 * @package Teknisa\FIN\Modules\ContaPagar\Factory
 */
class ParcelamentoTituloFactory {

    protected $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /**
     * Busca Boleto a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return BoletPagar
     */
    public function buscaBoletPagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findOneBy($params);

        return $boletpagar;
    }

    /**
     * Busca Boleto a Pagar Original
     * @param $nrorg
     * @param $cdfilial
     * @param $nrorigbolpag
     * @return BoletPagar
     */
    public function buscaBoletPagarOriginal($nrorg, $cdfilial, $nrorigbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrorigbolpag'] = $nrorigbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findBy($params);

        return $boletpagar;
    }

    /**
     * Busca Rateio Conta a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrparcelapag
     * @param $nrseqvenpag
     * @return Ratctpagar
     */
    public function buscaRatctpagar($nrorg, $cdfilial, $nrlanctonf, $nrparcelapag, $nrseqvenpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['nrseqvenpag']  = $nrseqvenpag;

        /** @var Ratctpagar $ratctpagar */
        $ratctpagar = $this->entityManager->getRepository(Ratctpagar::class)->findBy($params);

        return $ratctpagar;
    }

    /**
     * Busca Conta a Pagar
     * @param $nrorg
     * @param $cdfilibpag
     * @param $nrlanbolpag
     * @return Contapagar
     */
    public function buscaContapagarBoleto($nrorg, $cdfilibpag, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilibpag']  = $cdfilibpag;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Conta a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrparcelapag
     * @param $nrseqvenpag
     * @return Contapagar
     */
    public function buscaContapagar($nrorg, $cdfilial, $nrlanctonf, $nrparcelapag, $nrseqvenpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['nrseqvenpag']  = $nrseqvenpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Contas a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Contapagar
     */
    public function buscaContaspagar($nrorg, $cdfilial, $nrlanctonf){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdfilial']   = $cdfilial;
        $params['nrlanctonf'] = $nrlanctonf;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findBy($params);

        return $contapagar;
    }

    /**
     * Busca Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Ajbolpag
     */
    public function buscaAjbolpags($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Ajbolpag
     */
    public function buscaAjbolpag($nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;
        $params['cdajuctpag']  = $cdajuctpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findOneBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdajuctpag
     * @param $dtajustepag
     * @return Ajctpagar
     */
    public function buscaAjctpagar($nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $cdajuctpag, $dtajustepag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['cdajuctpag']   = $cdajuctpag;
        $params['dtajustepag']  = $dtajustepag;

        /** @var Ajctpagar $ajctpagar */
        $ajctpagar = $this->entityManager->getRepository(Ajctpagar::class)->findOneBy($params);

        return $ajctpagar;
    }

    /**
     * Busca Adiantamento Pagar
     * @param $nrorg
     * @param $cdfiliajbolp
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Adiantapagar
     */
    public function buscaAdiantapagar($nrorg, $cdfiliajbolp, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfiliajbolp'] = $cdfiliajbolp;
        $params['nrlanbolpag']  = $nrlanbolpag;
        $params['cdajuctpag']   = $cdajuctpag;

        /** @var Adiantapagar $adiantapagar */
        $adiantapagar = $this->entityManager->getRepository(Adiantapagar::class)->findOneBy($params);

        return $adiantapagar;
    }

    /**
     * Busca Devolução Pagar
     * @param $nrorg
     * @param $cdfilibolpag
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Devolucaopag
     */
    public function buscaDevolucaopag($nrorg, $cdfilibolpag, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilibolpag'] = $cdfilibolpag;
        $params['nrlanbolpag']  = $nrlanbolpag;
        $params['cdajuctpag']   = $cdajuctpag;

        /** @var Devolucaopag $devolucaopag */
        $devolucaopag = $this->entityManager->getRepository(Devolucaopag::class)->findOneBy($params);

        return $devolucaopag;
    }

    /**
     * Busca Nota Fiscal
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Notafiscal
     */
    public function buscaNotafiscal($nrorg, $cdfilial, $nrlanctonf){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdfilial']   = $cdfilial;
        $params['nrlanctonf'] = $nrlanctonf;

        /** @var Notafiscal $notafiscal */
        $notafiscal = $this->entityManager->getRepository(Notafiscal::class)->findOneBy($params);

        return $notafiscal;
    }

    /**
     * Insere Conta a Pagar
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdfilibpag
     * @param $nrlanbolpag
     * @param $vratuapag
     * @param $cdmotiparc
     * @param $vrorigpag
     * @param $dtatuavenpag
     * @param $cdempresa
     * @param $cdfimovflpag
     * @param $cdclassfina
     * @param $dtmovfluxo
     * @param $idmovfluxo
     * @param $qtdiasvenpag
     * @param $idstatpag
     * @param $cdtpctpagar
     * @param $dtorigvenpag
     * @param $dscontapag
     * @param $nrorg
     * @return Contapagar
     */
    public function insereContapagar(
        $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $nrparcelapagvisu, $cdfilibpag, $nrlanbolpag, $vratuapag, $cdmotiparc,
        $vrorigpag, $dtatuavenpag, $cdempresa, $cdfimovflpag, $cdclassfina, $dtmovfluxo, $idmovfluxo, $qtdiasvenpag,
        $idstatpag, $cdtpctpagar, $dtorigvenpag, $dscontapag, $nrorg
    ){
        /** @var Contapagar $contapagar */
        $contapagar = new Contapagar();
        $contapagar->setNrorg($nrorg);
        $contapagar->setCdfilial($cdfilial);
        $contapagar->setNrlanctonf($nrlanctonf);
        $contapagar->setNrseqvenpag($nrseqvenpag);
        $contapagar->setNrparcelapag($nrparcelapag);
        $contapagar->setNrparcelapagvisu($nrparcelapagvisu);
        $contapagar->setCdfilibpag($cdfilibpag);
        $contapagar->setNrlanbolpag($nrlanbolpag);
        $contapagar->setVratuapag($vratuapag);
        $contapagar->setCdmotiparc($cdmotiparc);
        $contapagar->setVrorigpag($vrorigpag);
        $contapagar->setDtatuavenpag($dtatuavenpag);
        $contapagar->setCdempresa($cdempresa);
        $contapagar->setCdfimovflpag($cdfimovflpag);
        $contapagar->setCdclassfina($cdclassfina);
        $contapagar->setDtmovfluxo($dtmovfluxo);
        $contapagar->setIdmovfluxo($idmovfluxo);
        $contapagar->setQtdiasvenpag($qtdiasvenpag);
        $contapagar->setIdstatpag($idstatpag);
        $contapagar->setCdtpctpagar($cdtpctpagar);
        $contapagar->setDtorigvenpag($dtorigvenpag);
        $contapagar->setDscontapag($dscontapag);
        $contapagar->setDtinclusao(DateUtil::getDataAtual());

        return $contapagar;
    }

    /**
     * Insere Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Boletpagar
     */
    public function insereBoletpagar(
        $nrorg, $cdfilial, $nrlanbolpag
    ){
        /** @var Boletpagar $boletpagar */
        $boletpagar = new Boletpagar();
        $boletpagar->setNrorg($nrorg);
        $boletpagar->setCdfilial($cdfilial);
        $boletpagar->setNrlanbolpag($nrlanbolpag);

        return $boletpagar;
    }

    /**
     * Insere Rateio Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdcentcust
     * @param $cdfiratctpag
     * @param $vrratccctpag
     * @return Ratctpagar
     */
    public function insereRatctpagar(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $cdcentcust,$cdfiratctpag, $vrratccctpag
    ){
        /** @var Ratctpagar $ratctpagar */
        $ratctpagar = new Ratctpagar();
        $ratctpagar->setNrorg($nrorg);
        $ratctpagar->setCdfilial($cdfilial);
        $ratctpagar->setNrlanctonf($nrlanctonf);
        $ratctpagar->setNrseqvenpag($nrseqvenpag);
        $ratctpagar->setNrparcelapag($nrparcelapag);
        $ratctpagar->setCdcentcust($cdcentcust);
        $ratctpagar->setCdfiratctpag($cdfiratctpag);
        $ratctpagar->setVrratccctpag($vrratccctpag);
        $ratctpagar->setDtinclusao(DateUtil::getDataAtual());

        return $ratctpagar;
    }

    /**
     * Insere Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $dtajustepag
     * @param $cdajuctpag
     * @param $dsajustepag
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdclassfina
     * @param $cdemmfajcntp
     * @param $cdfimfajcntp
     * @param $dtmovfluxo
     * @param $idmovfluxo
     * @param $vrajustepag
     * @return Ajctpagar
     */
    public function insereAjctpagar(
        $nrorg, $cdfilial, $nrlanctonf, $dtajustepag, $cdajuctpag, $dsajustepag,$nrseqvenpag, $nrparcelapag,
        $cdclassfina, $cdemmfajcntp, $cdfimfajcntp, $dtmovfluxo, $idmovfluxo, $vrajustepag
    ){
        /** @var Ajctpagar $ratctpagar */
        $ajctpagar = new Ajctpagar();
        $ajctpagar->setNrorg($nrorg);
        $ajctpagar->setCdfilial($cdfilial);
        $ajctpagar->setNrlanctonf($nrlanctonf);
        $ajctpagar->setDtajustepag($dtajustepag);
        $ajctpagar->setCdajuctpag($cdajuctpag);
        $ajctpagar->setDsajustepag($dsajustepag);
        $ajctpagar->setNrseqvenpag($nrseqvenpag);
        $ajctpagar->setNrparcelapag($nrparcelapag);
        $ajctpagar->setCdclassfina($cdclassfina);
        $ajctpagar->setCdemmfajcntp($cdemmfajcntp);
        $ajctpagar->setCdfimfajcntp($cdfimfajcntp);
        $ajctpagar->setDtmovfluxo($dtmovfluxo);
        $ajctpagar->setIdmovfluxo($idmovfluxo);
        $ajctpagar->setVrajustepag($vrajustepag);
        $ajctpagar->setDtinclusao(DateUtil::getDataAtual());

        return $ajctpagar;
    }

    /**
     * Insere Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @param $vrajbolpag
     * @return Ajbolpag
     */
    public function insereAjbolpag(
        $nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag, $vrajbolpag
    ){
        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = new Ajbolpag();
        $ajbolpag->setNrorg($nrorg);
        $ajbolpag->setCdfilial($cdfilial);
        $ajbolpag->setNrlanbolpag($nrlanbolpag);
        $ajbolpag->setCdajuctpag($cdajuctpag);
        $ajbolpag->setVrajbolpag($vrajbolpag);
        $ajbolpag->setDtinclusao(DateUtil::getDataAtual());

        return $ajbolpag;
    }

    /**
     * Insere Adiantamento Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdfiliajbolp
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Adiantapagar
     */
    public function insereAdiantapagar(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $cdfiliajbolp,$nrlanbolpag, $cdajuctpag
    ){
        /** @var Adiantapagar $adiantapagar */
        $adiantapagar = new Adiantapagar();
        $adiantapagar->setNrorg($nrorg);
        $adiantapagar->setCdfilial($cdfilial);
        $adiantapagar->setNrlanctonf($nrlanctonf);
        $adiantapagar->setNrseqvenpag($nrseqvenpag);
        $adiantapagar->setNrparcelapag($nrparcelapag);
        $adiantapagar->setCdfiliajbolp($cdfiliajbolp);
        $adiantapagar->setNrlanbolpag($nrlanbolpag);
        $adiantapagar->setCdajuctpag($cdajuctpag);
        $adiantapagar->setDtinclusao(DateUtil::getDataAtual());

        return $adiantapagar;
    }

    /**
     * Insere Devolucao Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @param $vrdevolucaopag
     * @return Devolucaopag
     */
    public function insereDevolucaopag(
        $nrorg, $cdfilial, $nrlanctonf, $nrlanbolpag, $cdajuctpag, $vrdevolucaopag
    ){
        /** @var Devolucaopag $devolucaopag */
        $devolucaopag = new Devolucaopag();
        $devolucaopag->setNrorg($nrorg);
        $devolucaopag->setCdfilial($cdfilial);
        $devolucaopag->setNrlanctonf($nrlanctonf);
        $devolucaopag->setNrlanbolpag($nrlanbolpag);
        $devolucaopag->setCdajuctpag($cdajuctpag);
        $devolucaopag->setVrdevolucaopag($vrdevolucaopag);
        $devolucaopag->setDtinclusao(DateUtil::getDataAtual());

        return $devolucaopag;
    }

    /**
     * Atualiza Rateio Conta Pagar Valor
     * @param Ratctpagar $ratctpagar
     * @param $vrratccctpag
     * @return Ratctpagar
     */
    public function atualizaRatctpagarValor(
        Ratctpagar $ratctpagar, $vrratccctpag
    ){
        $ratctpagar->setVrratccctpag($vrratccctpag);
        
        return $ratctpagar;
    }

    /**
     * Atualiza Boleto Pagar Original
     * @param Boletpagar $boletpagar
     * @param $vrfinalbpag
     * @param $dtvenbolpag
     * @param $dslinhbarpag
     * @param $cdbarrapag
     * @param $cdnosnumpag
     * @param $idsitucnabp
     * @param $nrcnabpagrem
     * @param $vrbolpag
     * @param $idstatbpag
     * @param $cdmotiparc
     * @param $nrbaixapag
     * @param $cdfilibaipag
     * @param $nrparcbolpag
     * @param $nrorigbolpag
     * @return Boletpagar
     */
    public function atualizaBoletpagarOriginal(
        Boletpagar $boletpagar, $vrfinalbpag, $dtvenbolpag, $dslinhbarpag, $cdbarrapag, $cdnosnumpag,
        $idsitucnabp, $nrcnabpagrem, $vrbolpag, $idstatbpag, $cdmotiparc, $nrbaixapag, $cdfilibaipag,
        $nrparcbolpag, $nrparcbolpagvisu, $nrorigbolpag, $vrmordiabpag, $vrmultabpag
    ){
        $boletpagar->setVrfinalbpag($vrfinalbpag);
        $boletpagar->setDtvenbolpag($dtvenbolpag);
        $boletpagar->setDslinhbarpag($dslinhbarpag);
        $boletpagar->setCdbarrapag($cdbarrapag);
        $boletpagar->setCdnosnumpag($cdnosnumpag);
        $boletpagar->setIdsitucnabp($idsitucnabp);
        $boletpagar->setNrcnabpagrem($nrcnabpagrem);
        $boletpagar->setVrbolpag($vrbolpag);
        $boletpagar->setIdstatbpag($idstatbpag);
        $boletpagar->setCdmotiparc($cdmotiparc);
        $boletpagar->setNrbaixapag($nrbaixapag);
        $boletpagar->setCdfilibaipag($cdfilibaipag);
        $boletpagar->setNrparcbolpag($nrparcbolpag);
        $boletpagar->setNrparcbolpagvisu($nrparcbolpagvisu);
        $boletpagar->setNrorigbolpag($nrorigbolpag);
        $boletpagar->setVrmordiabpag($vrmordiabpag);
        $boletpagar->setVrmultabpag($vrmultabpag);

        return $boletpagar;
    }

    /**
     * Atualiza Boleto Pagar Novo
     * @param Boletpagar $boletpagar
     * @param $dtvenbolpag
     * @param $nrorigbolpag
     * @param $cdforneced
     * @param $cdempresa
     * @param $cdreducont
     * @param $vrpemulbpag
     * @param $vrmultabpag
     * @param $vrpemorbpag
     * @param $vrmordiabpag
     * @param $cdtpbaixapag
     * @param $idstatbpag
     * @param $idsitucnabp
     * @param $vrbolpag
     * @param $cdmotiparc
     * @param $vrfinalbpag
     * @param $nrparcbolpag
     * @param $nrparcbolpagvisu
     * @param $nrbaixapag
     * @param $cdbarrapag
     * @param $cdnosnumpag
     * @param $cdfilibaipag
     * @param $dslinhbarpag
     * @return Boletpagar
     */
    public function atualizaBoletpagarNovo(
        Boletpagar $boletpagar, $dtvenbolpag, $nrorigbolpag, $cdforneced, $cdempresa, $cdreducont,
        $vrpemulbpag, $vrmultabpag, $vrpemorbpag, $vrmordiabpag, $cdtpbaixapag, $idstatbpag, $idsitucnabp,
        $vrbolpag, $cdmotiparc, $vrfinalbpag, $nrparcbolpag, $nrparcbolpagvisu, $nrbaixapag, $cdbarrapag, $cdnosnumpag,
        $cdfilibaipag, $dslinhbarpag, $cdoperinclusao
    ){
        $boletpagar->setDtvenbolpag($dtvenbolpag);
        $boletpagar->setNrorigbolpag($nrorigbolpag);
        $boletpagar->setCdforneced($cdforneced);
        $boletpagar->setCdempresa($cdempresa);
        $boletpagar->setCdreducont($cdreducont);
        $boletpagar->setVrpemulbpag($vrpemulbpag);
        $boletpagar->setVrmultabpag($vrmultabpag);
        $boletpagar->setVrpemorbpag($vrpemorbpag);
        $boletpagar->setVrmordiabpag($vrmordiabpag);
        $boletpagar->setCdtpbaixapag($cdtpbaixapag);
        $boletpagar->setIdstatbpag($idstatbpag);
        $boletpagar->setIdsitucnabp($idsitucnabp);
        $boletpagar->setVrbolpag($vrbolpag);
        $boletpagar->setCdmotiparc($cdmotiparc);
        $boletpagar->setVrfinalbpag($vrfinalbpag);
        $boletpagar->setNrparcbolpag($nrparcbolpag);
        $boletpagar->setNrparcbolpagvisu($nrparcbolpagvisu);
        $boletpagar->setNrbaixapag($nrbaixapag);
        $boletpagar->setCdbarrapag($cdbarrapag);
        $boletpagar->setCdnosnumpag($cdnosnumpag);
        $boletpagar->setCdfilibaipag($cdfilibaipag);
        $boletpagar->setDslinhbarpag($dslinhbarpag);
        $boletpagar->setCdoperinclusao($cdoperinclusao);
        $boletpagar->setDtinclusao(DateUtil::getDataAtual());

        return $boletpagar;
    }

    /**
     * Atualiza Conta a Pagar
     * @param Contapagar $contapagar
     * @param $vratuapag
     * @param $vrorigpag
     * @param $dtatuavenpag
     * @param $idmovfluxo
     * @param $cdmotiparc
     * @param $nrparcelapag
     * @return Contapagar
     */
    public function atualizaContapagar(
        Contapagar $contapagar, $vratuapag, $vrorigpag, $dtatuavenpag, $idmovfluxo, $cdmotiparc,
        $nrparcelapag, $nrparcelapagvisu
    ){
        $contapagar->setVratuapag($vratuapag);
        $contapagar->setVrorigpag($vrorigpag);
        $contapagar->setDtatuavenpag($dtatuavenpag);
        $contapagar->setIdmovfluxo($idmovfluxo);
        $contapagar->setCdmotiparc($cdmotiparc);
        $contapagar->setNrparcelapag($nrparcelapag);
        $contapagar->setNrparcelapagvisu($nrparcelapagvisu);

        return $contapagar;
    }
    
    /**
     * Busca Conta de Origem do Parcelamento
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return array
     */
    public function buscaContaOrigParc(
        $nrorg, $cdfilial, $nrlanbolpag
    ){

        /** @var $params */
        $params = array();
        $params['P_NRORG']       = $nrorg;
        $params['P_CDFILIAL' ]   = $cdfilial;
        $params['P_NRLANBOLPAG'] = $nrlanbolpag;

        $sql = " SELECT 
                        CP.CDFILIAL    , CP.NRLANCTONF , NF.NRNOTAFISC  , NF.CDSERIE     , CP.NRSEQVENPAG ,
                        CP.NRPARCELAPAG, CP.DSCONTAPAG , CP.DTORIGVENPAG, CP.VRORIGPAG   , CP.DTATUAVENPAG,
                        CP.VRATUAPAG   , CP.NRLANBOLPAG, CP.CDCLASSFINA , CP.CDEMPRESA   , CP.CDFIMOVFLPAG,
                        CP.DTMOVFLUXO  , CP.IDMOVFLUXO ,  CP.CDMOTIPARC , CP.QTDIASVENPAG, CP.IDSTATPAG   ,
                        CP.CDFILIBPAG  , CP.CDTPCTPAGAR, AJ.VRAJUSTE    , CP.NRORG
                  FROM  
                    NOTAFISCAL   NF, CONTAPAGAR CP,
                    (SELECT A.CDFILIAL, A.NRLANCTONF, A.NRSEQVENPAG, A.NRPARCELAPAG, A.NRORG,
                            SUM(DECODE(TA.IDAJUCTPAG, 'A', A.VRAJUSTEPAG, A.VRAJUSTEPAG * (-1))) AS VRAJUSTE
                       FROM AJCTPAGAR A, TIPOAJPAGAR TA
                      WHERE A.NRORG      = TA.NRORG
                      AND   A.CDAJUCTPAG = TA.CDAJUCTPAG
                      GROUP BY A.CDFILIAL, A.NRLANCTONF, A.NRSEQVENPAG, A.NRPARCELAPAG, A.NRORG) AJ
                  WHERE
                    (CP.CDFILIBPAG   = :P_CDFILIAL       ) AND
                    (CP.NRLANBOLPAG  = :P_NRLANBOLPAG    ) AND
                    (CP.NRORG        = :P_NRORG          ) AND
                    (NF.CDFILIAL     = CP.CDFILIAL       ) AND
                    (NF.NRORG        = CP.NRORG          ) AND
                    (NF.NRLANCTONF   = CP.NRLANCTONF     ) AND
                    (CP.CDFILIAL     = AJ.CDFILIAL(+)    ) AND
                    (CP.NRLANCTONF   = AJ.NRLANCTONF(+)  ) AND
                    (CP.NRSEQVENPAG  = AJ.NRSEQVENPAG(+) ) AND
                    (CP.NRPARCELAPAG = AJ.NRPARCELAPAG(+))
                  ORDER BY
                    CP.CDFILIAL,
                    CP.NRLANCTONF,
                    CP.NRSEQVENPAG,
                    CP.NRPARCELAPAG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Busca Maxíma Conta do Parcelamento
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @return array
     */
    public function buscaMaxCntParc(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag
    ){

        /** @var $params */
        $params = array();
        $params['P_NRORG']       = $nrorg;
        $params['P_CDFILIAL' ]   = $cdfilial;
        $params['P_NRLANCTONF']  = $nrlanctonf;
        $params['P_NRSEQVENPAG'] = $nrseqvenpag;

        $sql = "SELECT
                  MAX(NRPARCELAPAG) AS MAXNRPARCPAG
                FROM
                  CONTAPAGAR
                WHERE
                  CDFILIAL    = :P_CDFILIAL    AND
                  NRLANCTONF  = :P_NRLANCTONF  AND
                  NRSEQVENPAG = :P_NRSEQVENPAG AND
                  NRORG       = :P_NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Busca Ajuste Conta
     * @param $nrorg
     * @param $cdfilibpag
     * @param $nrlanbolpag
     * @return array
     */
    public function buscaAjusteConta(
        $nrorg, $cdfilibpag, $nrlanbolpag
    ){

        /** @var $params */
        $params = array();
        $params['P_NRORG']       = $nrorg;
        $params['P_CDFILIBPAG']  = $cdfilibpag;
        $params['P_NRLANBOLPAG'] = $nrlanbolpag;

        $sql = "SELECT
                     AR.CDFILIAL,
                     AR.NRLANCTONF,
                     AR.NRSEQVENPAG,
                     AR.NRPARCELAPAG,
                     AR.DTAJUSTEPAG,
                     AR.DSAJUSTEPAG,
                     AR.CDAJUCTPAG,
                     TA.IDAJUCTPAG,
                     AR.CDCLASSFINA,
                     AR.CDEMMFAJCNTP,
                     AR.CDFIMFAJCNTP,
                     AR.DTMOVFLUXO,
                     AR.IDMOVFLUXO,
                     AR.VRAJUSTEPAG,
                     AR.NRORG
                  FROM
                     AJCTPAGAR   AR,
                     TIPOAJPAGAR TA,
                     CONTAPAGAR  CT
                  WHERE
                     (CT.CDFILIBPAG   = :P_CDFILIBPAG) AND
                     (CT.NRLANBOLPAG  = :P_NRLANBOLPAG)  AND
                     (AR.CDFILIAL     = CT.CDFILIAL)     AND
                     (AR.NRLANCTONF   = CT.NRLANCTONF)   AND
                     (AR.NRSEQVENPAG  = CT.NRSEQVENPAG)  AND
                     (AR.NRPARCELAPAG = CT.NRPARCELAPAG) AND
                     (TA.CDAJUCTPAG   = AR.CDAJUCTPAG)   AND
                     (CT.NRORG        = :P_NRORG)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Busca Valor Rateio Conta
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @return array
     */
    public function buscaValorRateioConta(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag
    ){

        /** @var $params */
        $params = array();
        $params['P_NRORG']        = $nrorg;
        $params['P_CDFILIAL']     = $cdfilial;
        $params['P_NRLANCTONF']   = $nrlanctonf;
        $params['P_NRSEQVENPAG']  = $nrseqvenpag;
        $params['P_NRPARCELAPAG'] = $nrparcelapag;

        $sql = " SELECT
                     RT.CDFILIAL,
                     RT.NRLANCTONF,
                     RT.NRSEQVENPAG,
                     RT.NRPARCELAPAG,
                     RT.CDCENTCUST,
                     RT.CDFIRATCTPAG,
                     RT.VRRATCCCTPAG,
                     CT.VRATUAPAG,
                     ((RT.VRRATCCCTPAG * 100)/CT.VRATUAPAG) AS NRPERCENTUAL
                  FROM
                     RATCTPAGAR RT,
                     CONTAPAGAR CT
                  WHERE
                     RT.CDFILIAL     = :P_CDFILIAL     AND
                     RT.NRLANCTONF   = :P_NRLANCTONF   AND
                     RT.NRSEQVENPAG  = :P_NRSEQVENPAG  AND
                     RT.NRPARCELAPAG = :P_NRPARCELAPAG AND
                     RT.NRORG        = :P_NRORG        AND
                     RT.CDFILIAL     = CT.CDFILIAL     AND
                     RT.NRLANCTONF   = CT.NRLANCTONF   AND
                     RT.NRSEQVENPAG  = CT.NRSEQVENPAG  AND
                     RT.NRPARCELAPAG = CT.NRPARCELAPAG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca Número Parcela Alfanumérico
     * @param $nrpacela
     * @return array
     */
    public function buscaNrpacerlapagAlfa($nrpacela){
        $params = array();
        $params['P_NRPARCELA'] = $nrpacela;
        $sql = "SELECT RETORNA_COD_PARC(:P_NRPARCELA) NRPARCELAALFA FROM DUAL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

}